# first installation and setup

## get your accounts from WizardTales

1. [get an opencode prod gitlab account](https://gitlab.opencode.de/) [register here](https://opencode.de/en/registrieren)
2. [get an opencode dev gitlab account](https://dev-kpi.o4oe.de/)
3. optional [get an account for Rancher](https://kommone.cva-12889ja7.wizardtales.net)
4. optional check if you have access to the `subcluster1` in Rancher

## setup local folder structure

1. We have a recommended folder structure for developers, some scripts expecting it:
    ```
    opencode
    ├── data-provider (this repo)
    ├── dashboard
    └── sublcuster1.yaml (optional kubeconfig)
    ```
2. [add ssh key for authentification and commit signing](https://gitlab.opencode.de/-/user_settings/ssh_keys)
    - [local setup](https://docs.gitlab.com/ee/user/project/repository/signed_commits/ssh.html)
3. install Docker, we are using "docker compose" (v2)
4. for terminal stuff we suggest using the venv `source venv`

### setup IDE

1. We are using EditorConfig so check your plugins if `.editorconfig` is used
2. fill and follow our tasks in `.env` file
3. check `./gradlew tasks` for opencode
4. application requires the database and you may want to run the dashboard
    - recommended before : `./gradlew run-db run-dashboard`
    - run inside of docker with `./gradlew run-container`
    - run outside of container:
        1. `source venv`
            - loads every `.env` entry as environment variable
            - provides some alias
        2. `gradlew` which defaults to `./gradlew run`
5. verify by checking the dashboard on port 5000, after a few seconds there should be example projects

#### setup IntelliJ Ultimate for debugging

IntelliJ Ultimate provides support for Spring Boot and has the best support for Kotlin.
1. read and follow setup IDE
2. in `.run` is a default configurations to run and debug the application
   - start the database via gradle task `run-db`
   - start the dashboard via gradle task `run-dashboard`

### access database

- local database, for IntelliJ Ultimate you can connect to the `local` database via the right side of Tool window bars `Database`
  - copy source below and choose `New` →  `Import from Clipboard`
  - You may need to install the driver at the bottom
  ```
  #DataSourceSettings#
  #LocalDataSource: dataprovider@localhost
  #BEGIN#
  <data-source source="LOCAL" name="dataprovider@localhost" uuid="96dd947d-5c34-4a2b-bcfd-3f8039edb8e8"><database-info product="PostgreSQL" version="13.0.0" jdbc-version="4.2" driver-name="PostgreSQL JDBC Driver" driver-version="42.6.0" dbms="COCKROACH" exact-version="24.1.2" exact-driver-version="42.6"><identifier-quote-string>&quot;</identifier-quote-string></database-info><case-sensitivity plain-identifiers="lower" quoted-identifiers="exact"/><driver-ref>cockroach</driver-ref><synchronize>true</synchronize><jdbc-driver>org.postgresql.Driver</jdbc-driver><jdbc-url>jdbc:postgresql://localhost:26257/dataprovider</jdbc-url><jdbc-additional-properties><property name="com.intellij.clouds.kubernetes.db.host.port"/><property name="com.intellij.clouds.kubernetes.db.enabled" value="false"/><property name="com.intellij.clouds.kubernetes.db.container.port"/></jdbc-additional-properties><secret-storage>master_key</secret-storage><user-name>sa</user-name><schema-mapping><introspection-scope><node kind="database" qname="@"><node kind="schema" qname="@"/></node></introspection-scope></schema-mapping><working-dir>$ProjectFileDir$</working-dir></data-source>
  #END#
  ```
- `dev` / `prod` database, there is currently no official way of debugging the databases

### setup kubernetes

1. [Get the kubernetes version of our cluster:](https://kommone.cva-12889ja7.wizardtales.net/dashboard/c/c-gqst2/explorer#cluster-events)
    - e.g. Kubernetes Version: v1.25.12
    - the used provider could be relevant later, e.g. RKE1 = Rancher Kubernetes Engine 1
2. K8s support only one minor version step, so for 1.25 you can at max use kubectl 1.26 (e.g. v1.26.15)
    - install via: https://kubernetes.io/docs/tasks/tools/install-kubectl-linux/
    - depending on your installation route you may need: [github release](https://github.com/kubernetes/kubernetes/releases)
3. download the KubeConfig file `subcluster1.yaml` from [Rancher dashboard](https://kommone.cva-12889ja7.wizardtales.net/dashboard/c/c-gqst2/explorer)
    - use your config via `export KUBECONFIG=/$HOME/Downloads/subcluster1.yaml`
    - or providing it via: `--kubeconfig`
    - or move/rename this file to `~/.kube/config`
4. validate if your config got picked up, is this command successful?: `kubectl --namespace fraunhofer get pods`
    - if you using the OpenCoDE venv just use `dev get pods` or `prod get pods`
